Description
===========

This role provides base methods for each system role.

Requirement
===========

function defined variables
--------------------------

- function_packages (for container creation)

User defined variables
----------------------

- users
- usergroups
- network.hostname
- timezone

Variables
---------

* system_home_mirror:
  * description:
    * URL of the producer's package repository
  * hint: This variable is set by each system.

* system_local_mirror:
  * description:
    * URL of the local package repository

* system_mirror_directory:
  * description:
    * path to the root mirror directory on system for all system
  * hint: This variable is set by function role.

* system_supported_architures:
  * description:
    * list of system architectures supported by the system role; needed for installer und mirror
  * hint: This variable is set by each system.

* system_supported_releases:
  * description:
    * list of system releases supported by the system role; needed for installer und mirror
  * hint: This variable is set by each system.

* system_container_base_config:
  * description:
    * path to the base configuration file for containers
  * hint: default file is provided by this system role

* system_container_root: 
  * description:
    * path to the root directory for each jail 
  * hint: default file is provided by this system role

* system_suppress_container_creation:
  * description:
    * If this option is set to true, the system will be prepared for container usage, but none will be installed.
  * choises: [true, false]
  * default: false

* system_installer_path:
  * description:
    * destination path to the directory for the installer

* system_answer_path:
  * description:
    * destination path to the directory for the answer file

* system_name:
  * description:
    * contains the distribution name of a system; needed for gatherpackages

* system_gathered_packages:
  * description:
    * list of all packages; result of gatherpackages 

* system_upgrade_states:
  * description:
    * a dictionary with the results of upgrade (see features)

* system_app_root:
  * description:
    * contains the general path for applications without final path separator
    * must be set in defaults/main.yml of each system role 
  * examples:
    * Linux: system_app_root: "/usr"
    * FreeBSD: system_app_root: "/usr/local"
    * OpenBSD: system_app_root: "/usr/local"
    * NetBSD: system_app_root: "/usr/pkg"
  * default: undefined

* system_config_directory:
  * description:
    * contains the general path for configuration files of applications without final path separator
    * must be set in defaults/main.yml of each system role 
  * examples:
    * Linux: system_app_root: "/etc"
    * FreeBSD: system_app_root: "/usr/local/etc"
    * OpenBSD: system_app_root: "/etc"
    * NetBSD: system_app_root: "/usr/pkg/etc"
  * default: undefined
  
* system_default_gateways:
  * description_
    * This option is a dictionary and contains the default gateways of the processed host.
    * The key *ipv4* contains the IPv4 default gateway and the key *ipv6* the IPv6 default gateway.
    * This option is automatically generated in the *configure*-tasks. 

* system_resolver_info:
  * This option is a dictionary and contains the DNS search domains and the nameservers of the processed host.
  * The key *domains* contains a list of all DNS search domains and the key *servers* a list of all DNS nameservers.
  * This option is automatically generated in the *configure*-tasks. 

Processes
=========

main
----
1. execute system configuration (see configure)

configure
---------

1. collect the default gateway(s) and DNS resolver data
2. set hostname 
3. remove obsolete groups
4. remove obsolete users
5. add groups
6. add users  
7. append groups to users, if defined
8. set timezone

Features
========

The task upgrade have to generate a dictionary with the states of upgrade process. The dictionary has following structure:

<inventory\_hostname>:
    host: True|False
    <name of container 1>: True|False
    ...
    <name container n>: True|False

The key `host` contains the upgrade state of the inventory host. 
The state `True` means that the host or container was upgraded. `False` that there are no upgrades for them. 

